=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2013-11-18 15:04:32 +0000
+++ CMakeLists.txt	2013-12-11 12:56:14 +0000
@@ -25,6 +25,14 @@
 # (regarding syntax consistency, see http://pad.lv/1181187)
 set(GETTEXT_PACKAGE "address-book-app")
 
+option(CLICK_MODE "Installs to a contained location" off)
+if(CLICK_MODE)
+    set(APP_PACKAGE_NAME "com.ubuntu.address-book")
+    set(CMAKE_INSTALL_PREFIX /)
+    set(CMAKE_INSTALL_BINDIR /)
+    set(CLICK_TAG click)
+endif(CLICK_MODE)
+
 # Tests
 enable_testing()
 
@@ -40,6 +48,7 @@
 add_subdirectory(src)
 add_subdirectory(po)
 add_subdirectory(tests)
+add_subdirectory(click)
 
 # uninstall target
 configure_file("${CMAKE_CURRENT_SOURCE_DIR}/cmake_uninstall.cmake.in"

=== added file 'README.click'
--- README.click	1970-01-01 00:00:00 +0000
+++ README.click	2013-12-11 12:56:14 +0000
@@ -0,0 +1,15 @@
+Building for click
+==================
+
+To build for a click package configure cmake as:
+
+mkdir build
+cd build
+cmake [path_to_this_location] -DINSTALL_TESTS=off -DCLICK_MODE=on \
+    -DBZR_REVNO=$(cd [path_to_this_location]; bzr revno)
+make DESTDIR=package install
+click build package
+
+This package can be installed by running:
+
+pkcon install-local com.ubuntu.address-book_*.click

=== added directory 'click'
=== added file 'click/CMakeLists.txt'
--- click/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ click/CMakeLists.txt	2013-12-11 12:56:14 +0000
@@ -0,0 +1,10 @@
+if(CLICK_MODE)
+    if(NOT BZR_REVNO)
+        set(BZR_REVNO "latest")
+    endif(NOT BZR_REVNO)
+    configure_file(manifest.json.in ${CMAKE_CURRENT_BINARY_DIR}/manifest.json)
+    install(FILES ${CMAKE_CURRENT_BINARY_DIR}/manifest.json
+            DESTINATION ${CMAKE_INSTALL_PREFIX})
+    install(FILES address-book-apparmor.json
+            DESTINATION ${CMAKE_INSTALL_PREFIX})
+endif(CLICK_MODE)

=== added file 'click/address-book-apparmor.json'
--- click/address-book-apparmor.json	1970-01-01 00:00:00 +0000
+++ click/address-book-apparmor.json	2013-12-11 12:56:14 +0000
@@ -0,0 +1,8 @@
+{
+    "policy_groups": ["accounts",
+                      "contacts",
+                      "content_exchange",
+                      "content_exchange_source",
+                      ],
+    "policy_version": 1.0
+}

=== added file 'click/manifest.json.in'
--- click/manifest.json.in	1970-01-01 00:00:00 +0000
+++ click/manifest.json.in	2013-12-11 12:56:14 +0000
@@ -0,0 +1,21 @@
+{
+    "description":
+        "Address Book application to manager contacts",
+    "framework": "ubuntu-sdk-13.10",
+    "architecture": "armhf",
+    "hooks": {
+        "address-book": {
+            "apparmor": "address-book-apparmor.json",
+            "desktop": "@CMAKE_INSTALL_DATADIR@/applications/@DESKTOP_FILE@"
+        }
+    },
+    "icon": "share/icons/ubuntu-mobile/app/144/contacts-app.png",
+    "maintainer": "Ubuntu Developers <ubuntu-devel-discuss@lists.ubuntu.com>",
+    "name": "@APP_PACKAGE_NAME@",
+    "title": "Address Book",
+    "version": "2.9.1",
+    "x-source": {
+        "vcs-bzr": "lp:address-book-app",
+        "vcs-bzr-revno": "@BZR_REVNO@"
+    }
+}

=== modified file 'src/app/CMakeLists.txt'
--- src/app/CMakeLists.txt	2013-10-07 20:09:42 +0000
+++ src/app/CMakeLists.txt	2013-12-11 12:56:14 +0000
@@ -6,7 +6,6 @@
     ${CMAKE_BINARY_DIR}
 )
 
-
 set(ADDRESS_BOOK_APP_SRCS
     addressbookapp.h
     addressbookapp.cpp

